#
# str2duzk.awk - convert plain text to drive_uzk stroke info
#   by uratan! 2011.12.18
#
# embed raw ^M for RETURN,
#           ^[ for ESCAPE,
#           ^H for BACK_SPACE
#
BEGIN {
	#
	# specify 101 for us keyboard, 106 for JIS keyboard
	#
	init_tab(106);

	#
	# capture screen with "ScreenGrab" by every key stroke
	#
	trigger_ScreenGrab = 0;

	#
	# make delay to change window focus
	#
	print "D 3000		# wait 3sec";
}
{
	print "### " $0;
	shift = 0;

	len = length($0);
	for(i=1; i<=len; i++) {
		c = substr($0, i, 1);
		k = tab[c];
		if(match(k, /^t/)) {
			if(shift==1) {
				print release_shift;
				shift = 0;
			}
			sub(/^t/, "T", k);
			print k;
		} else {
			if(shift==0) {
				print press_shift;
				shift = 1;
			}
			print k;
		}

		if(trigger_ScreenGrab) {
			if(shift==1) {
				print release_shift;
			}
			print "D 200";
			print "T 0x3a		F1";
			print "D 200";
			if(shift==1) {
				print press_shift;
			}
		}
	}

	if(shift==1) {
		print release_shift;
		shift = 0;
	}
}

#
# conversion table
#   t means without shift, T with SHIFT
#
function init_tab(keyb_type)
{
	press_shift   = "P 0xe1		SHIFT(left)";
	release_shift = "r 0xe1		SHIFT(left)";

	tab["
"]= "t 0x28		RETURN";
	tab[""]= "t 0x29		ESCAPE";
	tab[""]= "t 0x2a		BACK_SPACE";
	tab["\t"]= "t 0x2b		TAB";

	tab[" "] = "t 0x2c		SPACE";
	tab["!"] = "T 0x1e		(1/!)";
	tab["#"] = "T 0x20		(3/#)";
	tab["$"] = "T 0x21		(4/$)";
	tab["%"] = "T 0x22		(5/%)";
	tab[","] = "t 0x36		(,/<)";
	tab["-"] = "t 0x2d		(-/=) [-/_]";
	tab["."] = "t 0x37		(./>)";
	tab["/"] = "t 0x38		(//?)";
	tab["0"] = "t 0x27		(0)   [0/)]";
	tab["1"] = "t 0x1e		(1/!)";
	tab["2"] = "t 0x1f		(2/\") [2/@]";
	tab["3"] = "t 0x20		(3/#)";
	tab["4"] = "t 0x21		(4/$)";
	tab["5"] = "t 0x22		(5/%)";
	tab["6"] = "t 0x23		(6/&) [6/^]";
	tab["7"] = "t 0x24		(7/') [7/&]";
	tab["8"] = "t 0x25		(8/() [8/*]";
	tab["9"] = "t 0x26		(9/)) [9/(]";
	tab[";"] = "t 0x33		(;/+) [;/:]";
	tab["<"] = "T 0x36		(,/<)";
	tab[">"] = "T 0x37		(./>)";
	tab["?"] = "T 0x38		(//?)";
	tab["A"] = "T 0x04		(A)";
	tab["B"] = "T 0x05		(B)";
	tab["C"] = "T 0x06		(C)";
	tab["D"] = "T 0x07		(D)";
	tab["E"] = "T 0x08		(E)";
	tab["F"] = "T 0x09		(F)";
	tab["G"] = "T 0x0a		(G)";
	tab["H"] = "T 0x0b		(H)";
	tab["I"] = "T 0x0c		(I)";
	tab["J"] = "T 0x0d		(J)";
	tab["K"] = "T 0x0e		(K)";
	tab["L"] = "T 0x0f		(L)";
	tab["M"] = "T 0x10		(M)";
	tab["N"] = "T 0x11		(N)";
	tab["O"] = "T 0x12		(O)";
	tab["P"] = "T 0x13		(P)";
	tab["Q"] = "T 0x14		(Q)";
	tab["R"] = "T 0x15		(R)";
	tab["S"] = "T 0x16		(S)";
	tab["T"] = "T 0x17		(T)";
	tab["U"] = "T 0x18		(U)";
	tab["V"] = "T 0x19		(V)";
	tab["W"] = "T 0x1a		(W)";
	tab["X"] = "T 0x1b		(X)";
	tab["Y"] = "T 0x1c		(Y)";
	tab["Z"] = "T 0x1d		(Z)";
	tab["a"] = "t 0x04		(A)";
	tab["b"] = "t 0x05		(B)";
	tab["c"] = "t 0x06		(C)";
	tab["d"] = "t 0x07		(D)";
	tab["e"] = "t 0x08		(E)";
	tab["f"] = "t 0x09		(F)";
	tab["g"] = "t 0x0a		(G)";
	tab["h"] = "t 0x0b		(H)";
	tab["i"] = "t 0x0c		(I)";
	tab["j"] = "t 0x0d		(J)";
	tab["k"] = "t 0x0e		(K)";
	tab["l"] = "t 0x0f		(L)";
	tab["m"] = "t 0x10		(M)";
	tab["n"] = "t 0x11		(N)";
	tab["o"] = "t 0x12		(O)";
	tab["p"] = "t 0x13		(P)";
	tab["q"] = "t 0x14		(Q)";
	tab["r"] = "t 0x15		(R)";
	tab["s"] = "t 0x16		(S)";
	tab["t"] = "t 0x17		(T)";
	tab["u"] = "t 0x18		(U)";
	tab["v"] = "t 0x19		(V)";
	tab["w"] = "t 0x1a		(W)";
	tab["x"] = "t 0x1b		(X)";
	tab["y"] = "t 0x1c		(Y)";
	tab["z"] = "t 0x1d		(Z)";

	if(keyb_type == 101) {
		tab["\""]= "T 0x34		(:/*) ['/\"]";
		tab["&"] = "T 0x24		(7/') [7/&]";
		tab["'"] = "t 0x34		(:/*) ['/\"]";
		tab["("] = "T 0x26		(9/)) [9/(]";
		tab[")"] = "T 0x27		(0)   [0/)]";
		tab["*"] = "T 0x25		(8/() [8/*]";
		tab["+"] = "T 0x2e		(^/~) [=/+]";
		tab[":"] = "T 0x33		(;/+) [;/:]";
		tab["="] = "t 0x2e		(^/~) [=/+]";
		tab["@"] = "T 0x1f		(2/\") [2/@]";
		tab["["] = "t 0x2f		(@/`) [[/{]";
		tab["\\"]= "t 0x31		(]/}) [\\/|]";
		tab["]"] = "t 0x30		([/{) []/}]";
		tab["^"] = "T 0x23		(6/&) [6/^]";
		tab["_"] = "T 0x2d		(-/=) [-/_]";
		tab["`"] = "t 0x35		(KANJI/Hankaku_Zenkaku) [`/~]";
		tab["{"] = "T 0x2f		(@/`) [[/{]";
		tab["|"] = "T 0x31		(]/}) [\\/|]";
		tab["}"] = "T 0x30		([/{) []/}]";
		tab["~"] = "T 0x35		(KANJI/Hankaku_Zenkaku) [`/~]";
	} else {
		tab["\""]= "T 0x1f		(2/\") [2/@]";
		tab["&"] = "T 0x23		(6/&) [6/^]";
		tab["'"] = "T 0x24		(7/') [7/&]";
		tab["("] = "T 0x25		(8/() [8/*]";
		tab[")"] = "T 0x26		(9/)) [9/(]";
		tab["*"] = "T 0x34		(:/*) ['/\"]";
		tab["+"] = "T 0x33		(;/+) [;/:]";
		tab[":"] = "t 0x34		(:/*) ['/\"]";
		tab["="] = "T 0x2d		(-/=) [-/_]";
		tab["@"] = "t 0x2f		(@/`) [[/{]";
		tab["["] = "t 0x30		([/{) []/}]";
		tab["\\"]= "t 0x89		(\\/|)"
		tab["]"] = "t 0x31		(]/}) [\\/|]";
		tab["^"] = "t 0x2e		(^/~) [=/+]";
		tab["_"] = "T 0x87		(\\/_)"
		tab["`"] = "T 0x2f		(@/`) [[/{]";
		tab["{"] = "T 0x30		([/{) []/}]";
		tab["|"] = "T 0x89		(\\/|)"
		tab["}"] = "T 0x31		(]/}) [\\/|]";
		tab["~"] = "T 0x2e		(^/~) [=/+]";
	}
}
